==> wdigital-cms-site-tree-1.0.4-676193.zip: src/views/section/edit.php <==
<?php

use wdigital\cms\inspinia\widgets\SiteTree;
use yii\base\DynamicModel;
use yii\helpers\Html;
use yii\helpers\Url;
use yii\web\View;
use yii\widgets\ActiveForm;

/* @var $this View */
$this->title = Yii::t('section', Yii::t('section', 'Edit section :')) . $model->name;
$this->params['breadcrumbs'][] = ['label' => Yii::t('section', 'Site Tree'), 'url' => ['index']];
$this->params['breadcrumbs'][] = $this->title;
?>
<div>
    <div class="row">
        <div class="col-lg-6">
            <div class="ibox-title">
                <div class="ibox-tools">
                    <a class="btn btn-primary btn-xs" href="<?= Url::to(['add'])?>">
                        <?=  Yii::t('section', 'New section'); ?>
                    </a>
                </div>
            </div>
            <div class="ibox-content animated fadeInUp">
                <div hidden class="js-active-node-id" data-id="<?= $section->id?>"></div>
                <div id="jstree1">
                    <?php
                    $sitetree = new SiteTree();
                    echo $sitetree->renderTree($sections,'',true,'');

                    ?>

                </div>
            </div>
        </div>
        <div class="col-lg-6">
            <div class="ibox animated fadeInUp">
                <div class="ibox-title">
                    <h3><?= Html::encode($this->title) ?></h3>
                    <small><?= Yii::t('section', 'By submitting this form you are editing a section.') ?></small>
                </div>
                <div class="ibox-content">
                    <?php
                    $form = ActiveForm::begin([
                                'id' => 'edit-form',
                                'options' => ['role' => 'form', 'method' => 'POST'],
                                'action' => ['edit', 'id' => $section->id],
                            ])
                    ?>
                    <?= $form->field($section, 'parent_id')->dropDownList($parents, ['prompt' => [ 'text' => Yii::t('section', 'None'),
                                                                                                            'options' => ['value' => 0]]]) ?>
                    <?=
                    $form->field($section, 'type')->dropDownList([
                        'html'=> Yii::t('section', 'HTML'),
                        'redirect' => Yii::t('section', 'Redirect section'),
                        'gdpr' => Yii::t('section', 'GDPR section')
                    ])
                    ?>
                    <?= $form->field($section, 'name')->textInput(["data-slug-field" => "edit-name",'class'=>'form-control js-slug-field']) ?>
                    <?= $form->field($section, 'slug')->textInput(["data-slug-target" => "edit-name"]) ?>

                    <div class="form-group">
                        <?= Html::submitButton(Yii::t('section', 'Save'), ['class' => 'btn btn-primary', 'name' => 'edit-button']) ?>
                    </div>

                    <?php ActiveForm::end(); ?>
                </div>
            </div>
        </div>
    </div>
</div>

==> wdigital-cms-site-tree-1.0.6-3b246a.zip: src/views/section/edit.php <==
<?php

use wdigital\cms\inspinia\widgets\SiteTree;
use yii\base\DynamicModel;
use yii\helpers\Html;
use yii\helpers\Url;
use yii\web\View;
use yii\widgets\ActiveForm;

/* @var $this View */
$this->title = Yii::t('site-tree', 'Edit section :') . $model->name;
$this->params['breadcrumbs'][] = ['label' => Yii::t('site-tree', 'Site Tree'), 'url' => ['index']];
$this->params['breadcrumbs'][] = $this->title;
?>
<div>
    <div class="row">
        <div class="col-lg-6">
            <div class="ibox-title">
                <div class="ibox-tools">
                    <a class="btn btn-primary btn-xs" href="<?= Url::to(['add'])?>">
                        <?=  Yii::t('site-tree', 'New section'); ?>
                    </a>
                </div>
            </div>
            <div class="ibox-content animated fadeInUp">
                <div hidden class="js-active-node-id" data-id="<?= $section->id?>"></div>
                <div id="jstree1">
                    <?php
                    $sitetree = new SiteTree();
                    echo $sitetree->renderTree($sections,'',true,'');

                    ?>

                </div>
            </div>
        </div>
        <div class="col-lg-6">
            <div class="ibox animated fadeInUp">
                <div class="ibox-title">
                    <h3><?= Html::encode($this->title) ?></h3>
                    <small><?= Yii::t('site-tree', 'By submitting this form you are editing a section.') ?></small>
                </div>
                <div class="ibox-content">
                    <?php
                    $form = ActiveForm::begin([
                                'id' => 'edit-form',
                                'options' => ['role' => 'form', 'method' => 'POST'],
                                'action' => ['edit', 'id' => $section->id],
                            ])
                    ?>
                    <?= $form->field($section, 'parent_id')->dropDownList($parents, ['prompt' => [ 'text' => Yii::t('site-tree', 'None'),
                                                                                                            'options' => ['value' => 0]]]) ?>
                    <?=
                    $form->field($section, 'type')->dropDownList([
                        'html'=> Yii::t('site-tree', 'HTML'),
                        'redirect' => Yii::t('site-tree', 'Redirect section'),
                        'gdpr' => Yii::t('site-tree', 'GDPR section')
                    ])
                    ?>
                    <?= $form->field($section, 'name')->textInput(["data-slug-field" => "edit-name",'class'=>'form-control js-slug-field']) ?>
                    <?= $form->field($section, 'slug')->textInput(["data-slug-target" => "edit-name"]) ?>

                    <div class="form-group">
                        <?= Html::submitButton(Yii::t('site-tree', 'Save'), ['class' => 'btn btn-primary', 'name' => 'edit-button']) ?>
                    </div>

                    <?php ActiveForm::end(); ?>
                </div>
            </div>
        </div>
    </div>
</div>
